@@ -19,8 +19,8 @@ case "supera il numero totale di settimane della prenotazione":
 case "supera il numero totale di giorni della prenotazione":                             $messaggio = "ist gr&ouml;&szlig;er als die Anzahl der Tage f&uuml;r die Reservierung"; break;
 case "persone":                                                                          $messaggio = "Person(en)"; break;
 case "Si dovrà occupare almeno un periodo della regola di assegnazione 1":              $messaggio = "Mindestens eine Periode der Zuweisungsregel 1 wird zu beachten sein."; break;
-case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":              $messaggio = "Umbuchungen die im Zeitraum vorgenommen werden mssen <div style=\"display: inline; color: blue;\">Zuordnung zur Regel 1</div>"; break;
-case "Sono stati fatti i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":            $messaggio = "Umbuchungen die im Zeitraum vorgenommen wurden <div style=\"display: inline; color: blue;\">Zuordnung zur Regel 1</div>"; break;
+case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":                                                                                    $messaggio = "Umbuchungen die im Zeitraum vorgenommen werden mssen <div style=\"display: inline; color: blue;\">Zuordnung zur Regel 1</div>"; break;
+case "Sono stati fatti i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":                                                                                  $messaggio = "Umbuchungen die im Zeitraum vorgenommen wurden <div style=\"display: inline; color: blue;\">Zuordnung zur Regel 1</div>"; break;
 case "La prenotazione dal":                                                              $messaggio = "Die Reservierung vom"; break;
 case "a nome di":                                                                        $messaggio = "f&uuml;r Herrn/Frau"; break;
 case "Non si può procedere perchè la tabella prenotazioni è cambiata nel frattempo":  $messaggio = "Kann nicht fortfahren, weil sie die Reservierungstabelle inzwischen ge&auml;ndert hat."; break;
@@ -41,7 +41,6 @@ case "Utilizza il cliente":
 case "per la prenotazione":                                                              $messaggio = "f&uuml;r die Reservierung"; break;
 case "Modifica i dati del cliente":                                                      $messaggio = "Daten &auml;ndern von Kunde"; break;
 case "Inserisci un nuovo cliente":                                                       $messaggio = "Neuen Kunden anlegen"; break;
-case "É necessario inserire il cognome del cliente":                                    $messaggio = "Nachname des Kunden erforderlich"; break;
 case "I dati del cliente":                                                               $messaggio = "Gastdaten"; break;
 case "sono stati inseriti":                                                              $messaggio = "wurden eingetragen"; break;
 case "Inserisci o modifica i dati di un cliente":                                        $messaggio = "G&auml;ste erfassen"; break;
@@ -70,7 +69,7 @@ case "sono stati modificati":
 case "e":                                                                                $messaggio = "und"; break;
 case "Il numero di prenotazioni è sbagliato":                                           $messaggio = "Die Anzahl der Reservierungen ist falsch"; break;
 case "Aggiungi":                                                                         $messaggio = "Hinzuf&uuml;gen"; break;
-case "Nº di tipologie da aggiungere":                                                   $messaggio = "Anzahl der hinzuzuf&uuml;genden Typen"; break;
+case "Nº di tipologie da aggiungere":                                                   $messaggio = "Anzahl der Buchungsmasken, die hinzugef&uuml;gt werden sollen"; break;
 case "Non si è trovato nessun cliente chiamato":                                        $messaggio = "Es gibt keine Kunden mit Namen"; break;
 case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":                          $messaggio = "Es gibt keine Zeitr&auml;ume in Zuweisungsregel 1 die erlauben, die Reservierung einzutragen f&uuml;r den Kunden"; break;
 case "Il numero di persone è sbagliato":                                                $messaggio = "Die Anzahl der Personen ist falsch"; break;
@@ -107,7 +106,7 @@ case "città di nascita":
 case "reg./prov. di nascita":                                                            $messaggio = "Geburtsregion"; break;
 case "nazione di nascita":                                                               $messaggio = "Geburtsland"; break;
 case "Residenza":                                                                        $messaggio = "Wohnort"; break;
-case "reg./prov.":                                                                       $messaggio = "Beh&ouml;rde"; break;
+case "reg./prov.":                                                                       $messaggio = "Bezirk/Region"; break;
 case "nazione":                                                                          $messaggio = "Staat"; break;
 case "rilasciato da":                                                                    $messaggio = "ausgestellt von"; break;
 case "nazione di rilascio":                                                              $messaggio = "ausstellender Staat"; break;
@@ -122,8 +121,11 @@ case "lo sconto è sbagliato":
 case "la caparra è sbagliata":                                                          $messaggio = "die Anzahlung ist falsch"; break;
 case "soprannome":                                                                       $messaggio = "Nickname"; break;
 case "le commissioni sono sbagliate":                                                    $messaggio = "die Provisionen sind falsch"; break;
-case "lingua":  				$messaggio = "language"; break;
-case "ln.":  					$messaggio = "ln."; break;
+case "lingua":  				                                         $messaggio = "Sprache"; break;
+case "ln.":  					                                         $messaggio = "ln."; break;
+case "É necessario inserire il cognome del cliente":	$messaggio = "The client's surname is needed"; break;
+case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
+case "La tariffa richiesta è chiusa in questo periodo":	$messaggio = "The requested rate is closed in this period"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
