@@ -9,7 +9,7 @@ case "soprannominata":                                                   $messag
 case "Dal":                                                              $messaggio = "von"; break;
 case "al":                                                               $messaggio = "zu"; break;
 case "inserisci i nuovi prezzi":                                         $messaggio = "Neue Preise &uuml;bernehmen"; break;
-case "modifica i prezzi già inseriti":                                  $messaggio = "Bereits eingef&uuml;gte Preise ver&auml;ndern"; break;
+case "modifica i prezzi già inseriti":                                   $messaggio = "Bereits eingef&uuml;gte Preise ver&auml;ndern"; break;
 case "Costi aggiuntivi":                                                 $messaggio = "Zuschl&auml;ge"; break;
 case "Nome del nuovo costo aggiuntivo":                                  $messaggio = "Neue Bezeichnung f&uuml;r einen Zuschlag"; break;
 case "da applicare":                                                     $messaggio = "anzuwenden"; break;
@@ -33,10 +33,10 @@ case "Caparra":                                                          $messag
 case "La caparra normale per la":                                        $messaggio = "Die &uuml;bliche Anzahlung f&uuml;r"; break;
 case "arrotondata a":                                                    $messaggio = "gerundet zu"; break;
 case "Inserisci o modifica la caparra":                                  $messaggio = "Eingeben oder &auml;ndern der Anzahlung"; break;
-case "Vedi i prezzi già inseriti":                                      $messaggio = "Bisher eingegebene Preise anzeigen"; break;
-case "Torna al menù principale":                                        $messaggio = "Zum Hauptmen&uuml;"; break;
+case "Vedi i prezzi già inseriti":                                       $messaggio = "Bisher eingegebene Preise anzeigen"; break;
+case "Torna al menù principale":                                         $messaggio = "Zum Hauptmen&uuml;"; break;
 case "Si deve inserire la percentuale":                                  $messaggio = "Sie m&uuml;ssen den Prozentsatz angeben"; break;
-case "La caparra è stata modificata":                                   $messaggio = "Die Anzahlung wurde ge&auml;ndert"; break;
+case "La caparra è stata modificata":                                    $messaggio = "Die Anzahlung wurde ge&auml;ndert"; break;
 case "Si deve specificare quando applicare il costo di fine locazione":  $messaggio = "Sie m&uuml;ssen ausw&auml;hlen wie die Einmalkosten angewendet werden sollen"; break;
 case "Si deve inserire il nome del costo aggiuntivo":                    $messaggio = "Sie m&uuml;ssen den Namen des Zuschlags eingeben"; break;
 case "Il costo aggiuntivo finale":                                       $messaggio = "Einmalige Zuschl&auml;ge"; break;
@@ -54,30 +54,29 @@ case "Si deve specificare quando applicare il costo percentuale":        $messag
 case "e il valore dell'arrotondamento":                                  $messaggio = "und der Wert gerundet zu"; break;
 case "Per chiedere per quanto deve essere moltiplicato il costo aggiuntivo percentuale non deve essere applicato automaticamente":        $messaggio = "Um zu fragen wie oft es multipliziert werden mu&szlig; d&uuml;rfen die prozentualen Zuschl&auml;ge nicht automatisch angewendet werden."; break;
 case "Il costo aggiuntivo percentuale":                                  $messaggio = "Die prozentualen Zuschl&auml;ge"; break;
-case "è stato inserito":                                                $messaggio = "wurden eingetragen"; break;
-case "Nessun dato è stato inserito":  		$messaggio = "No data has been inserted"; break;
+case "è stato inserito":                                                 $messaggio = "wurden eingetragen"; break;
 case "Il soprannome della":                                              $messaggio = "Der Name von"; break;
 case "già esiste, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo o non metterlo per inserire prezzi per nuovi periodi":        $messaggio = "existiert bereits, benutzen Sie den Butten \"&Auml;ndern von bestehenden Preisen\" um es zu &auml;ndern oder tragen Sie nichts ein um Preise in neuen Zeitr&auml;umen anzugeben."; break;
 case "Il soprannome":                                                    $messaggio = "Der Name"; break;
-case "già esiste, ne devi usare un'altro":                              $messaggio = "existiert bereits, benutzen Sie einen anderen."; break;
+case "già esiste, ne devi usare un'altro":                               $messaggio = "existiert bereits, benutzen Sie einen anderen."; break;
 case "Le date del periodo numero":                                       $messaggio = "Die Daten des Zeitraumes Nummer"; break;
 case "sono sbagliate":                                                   $messaggio = "sind falsch"; break;
 case "Il periodo":                                                       $messaggio = "Der Zeitraum"; break;
 case "si sovrappone ad un periodo precedente":                           $messaggio = "&uuml;berschneidet sich mit einem anderen"; break;
 case "Un prezzo nel periodo numero":                                     $messaggio = "Ein Preis im Zeitraum Nummer"; break;
 case "esiste già, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo":        $messaggio = "existiert bereits, benutzen Sie den Knopf \"&Auml;ndern bereits existierender Preise\" um ihn zu &auml;ndern."; break;
-case "è stato cambiato":                                                $messaggio = "wurde ge&auml;ndert"; break;
-case "Il prezzo del periodo":                                            $messaggio = "Der Preis des Zeitraumes"; break;
-case "è stato inserito":                                                $messaggio = "wurden eingetragen"; break;
+case "è stato cambiato":                                                 $messaggio = "wurde ge&auml;ndert"; break;
+case "Il prezzo del periodo":                                            $messaggio = "Die Preise des Zeitraumes"; break;
+case "è stato inserito":                                                 $messaggio = "wurden eingetragen"; break;
 case "Il prezzo del periodo numero":                                     $messaggio = "Der Preis des Zeitraumes Nummer"; break;
-case "è sbagliato":                                                     $messaggio = "ist falsch"; break;
+case "è sbagliato":                                                      $messaggio = "ist falsch"; break;
 case "I soldi del costo finale sono sbagliati":                          $messaggio = "Der Betrag f&uuml;r die Einmalkosten ist falsch"; break;
 case "I soldi del costo settimanale sono sbagliati":                     $messaggio = "Der Betrag f&uuml;r die w&ouml;chentlichen Zuschl&auml;ge ist falsch"; break;
 case "I soldi del costo giornaliero sono sbagliati":                     $messaggio = "Der Betrag f&uuml;r die t&auml;glichen Zuschl&auml;ge ist falsch"; break;
 case "I soldi del costo percentuale sono sbagliati":                     $messaggio = "Der Betrag f&uuml;r die prozentualen Zuschl&auml;ge ist falsch"; break;
-case "Nome e tipo della tariffa, inserzione per settimane":              $messaggio = "Tarif&auml;nderung auf w&ouml;chentlicher Basis"; break;
-case "Nome e tipo della tariffa, inserzione per giorni":                 $messaggio = "Tarif&auml;nderung auf Tages-Basis"; break;
 case "Inserzione per settimane":                                         $messaggio = "Tarif&auml;nderung auf w&ouml;chentlicher Basis"; break;
+case "Inserzione per giorni":			$messaggio = "Preise auf t&auml;glicher Basis"; break;
+case "Inserzione per settimane":  		$messaggio = "Preise auf w&ouml;chentlicher Basis"; break;
 case "Settimane dal":                                                    $messaggio = "Wochen von"; break;
 case "Dom/Lun":                                                          $messaggio = "So/Mo"; break;
 case "Lun/Mar":                                                          $messaggio = "Mo/Di"; break;
@@ -88,7 +87,7 @@ case "Ven/Sab":                                                          $messag
 case "Sab/Dom":                                                          $messaggio = "Sa/So"; break;
 case "inserisci o modifica i prezzi":                                    $messaggio = "Eintragen oder &auml;ndern der Preise"; break;
 case "Le date sono sbagliate":                                           $messaggio = "Daten sind falsch"; break;
-case "Il formato dei soldi è sbagliato":                                $messaggio = "W&auml;hrungsformat ist falsch"; break;
+case "Il formato dei soldi è sbagliato":                                 $messaggio = "W&auml;hrungsformat ist falsch"; break;
 case "I prezzi per le settimane dal":                                    $messaggio = "Die Preise f&uuml;r die Wochen von"; break;
 case "della <b>tariffa":                                                 $messaggio = "des <b>Preises"; break;
 case "sono stati inseriti":                                              $messaggio = "wurde eingetragen"; break;
@@ -99,10 +98,6 @@ case "nessuna":                                                          $messag
 case "scegliere":                                                        $messaggio = "ausw&auml;hlen"; break;
 case "mostrare nella pagina di inserzione prenotazioni":                 $messaggio = "Auf der Seite zum Eintragen von Reservierungen anzeigen"; break;
 case "Torna indietro":                                                   $messaggio = "Zur&uuml;ck"; break;
-case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>finale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>single</b> extra cost"; break;
-case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>settimanale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>weekly</b> extra cost"; break;
-case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>giornaliero</b>":	$messaggio = "Choose the rates to which apply automatically the <b>daily</b> extra cost"; break;
-case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>percentuale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>percentage</b> extra cost"; break;
 case "Continua":                                                         $messaggio = "Weiter"; break;
 case "Tipo di costo aggiuntivo":                                         $messaggio = "H&auml;ufigkeit des Zuschlages"; break;
 case "unico":                                                            $messaggio = "einmalig"; break;
@@ -129,17 +124,17 @@ case "il primo":                                                         $messag
 case "l'ultima":                                                         $messaggio = "der letzte"; break;
 case "l'ultimo":                                                         $messaggio = "der letzte"; break;
 case "Chiedere":                                                         $messaggio = "Fragen"; break;
-case "settimane sì":                                                    $messaggio = "Wochen ja"; break;
-case "giorni sì":                                                       $messaggio = "Tage ja"; break;
+case "settimane sì":                                                     $messaggio = "Wochen ja"; break;
+case "giorni sì":                                                        $messaggio = "Tage ja"; break;
 case "settimane no":                                                     $messaggio = "Wochen nein"; break;
 case "giorni no":                                                        $messaggio = "Tage nein"; break;
 case "e":                                                                $messaggio = "und"; break;
 case "Giorni della settimana selezionati":                               $messaggio = "Ausgew&auml;hlte Wochentage"; break;
-case "Lunedì":                                                          $messaggio = "Montag"; break;
-case "Martedì":                                                         $messaggio = "Dienstag"; break;
-case "Mercoledì":                                                       $messaggio = "Mittwoch"; break;
-case "Giovedì":                                                         $messaggio = "Donnerstag"; break;
-case "Venerdì":                                                         $messaggio = "Freitag"; break;
+case "Lunedì":                                                           $messaggio = "Montag"; break;
+case "Martedì":                                                          $messaggio = "Dienstag"; break;
+case "Mercoledì":                                                        $messaggio = "Mittwoch"; break;
+case "Giovedì":                                                          $messaggio = "Donnerstag"; break;
+case "Venerdì":                                                          $messaggio = "Freitag"; break;
 case "Sabato":                                                           $messaggio = "Sonnabend"; break;
 case "Domenica":                                                         $messaggio = "Sonntag"; break;
 case "Moltiplicare il costo per":                                        $messaggio = "Kosten multiplizieren mit"; break;
@@ -148,7 +143,7 @@ case "Chiedere":                                                         $messag
 case "Numero di persone":                                                $messaggio = "Personenanzahl"; break;
 case "Numero di persone totale":                                         $messaggio = "Gesamtpersonenzahl"; break;
 case "escluse quelle dei costi con letti aggiuntivi":                    $messaggio = "ohne diejenigen Personen in Zusatzbetten"; break;
-case "Periodi in cui è permesso inserire il costo":                     $messaggio = "Zeitr&auml;ume in denen die Zuschl&auml;ge angewendet werden d&uuml;rfen"; break;
+case "Periodi in cui è permesso inserire il costo":                      $messaggio = "Zeitr&auml;ume in denen die Zuschl&auml;ge angewendet werden d&uuml;rfen"; break;
 case "In tutti":                                                         $messaggio = "Alle"; break;
 case "Solo nei periodi selezionati":                                     $messaggio = "Nur ausgew&auml;hlte Zeitr&auml;ume"; break;
 case "dal":                                                              $messaggio = "von"; break;
@@ -156,8 +151,6 @@ case "Elimina un periodo":                                               $messag
 case "Aggiungi un periodo":                                              $messaggio = "Zeitraum hinzuf&uuml;gen"; break;
 case "se tutte le settimane della prenotazione sono all'interno dei periodi selezionati":        $messaggio = "wenn alle Wochen der Reservierung innerhalb der ausgew&auml;hlten Zeitr&auml;ume liegen"; break;
 case "se tutti i giorni della prenotazione sono all'interno dei periodi selezionati":            $messaggio = "wenn alle Tage der Reservierung innerhalb der ausgew&auml;hlten Zeitr&auml;ume liegen"; break;
-case "se anche una sola settimana della prenotazione è all'interno dei periodi selezionati":	$messaggio = "if even only one week of the reservation is in the selected periods"; break;
-case "se anche un solo giorno della prenotazione è all'interno dei periodi selezionati":	$messaggio = "if even only one day of the reservation is in the selected periods"; break;
 case "applicare il costo solo in settimane permesse all'interno della prenotazione":             $messaggio = "Zuschl&auml;ge nur in den zugelassenen Wochen der Reservierung anwenden"; break;
 case "applicare il costo solo in giorni permessi all'interno della prenotazione":                $messaggio = "f&uuml;ge den Zuschlag nur an den zugelassenen Tagen hinzu"; break;
 case "Caratteristiche del costo da mantenere quando si modifica una prenotazione":               $messaggio = "Folgende Eigenschaften der Kosten sind beizubehalten, wenn eine Reservierung ge&auml;ndert wird:"; break;
@@ -192,12 +185,10 @@ case "I giorni a cui applicare il costo":                                $messag
 case "uno":                                                              $messaggio = "eins"; break;
 case "NO":                                                               $messaggio = "NEIN"; break;
 case "SI":                                                               $messaggio = "JA"; break;
-case "Costi aggiuntivo già esistente":                                  $messaggio = "Zuschlag bereits eingef&uuml;gt"; break;
 case "Tariffe incompatibili con il costo":                               $messaggio = "Preise mit Zuschlag nicht kompatibel"; break;
 case "Tariffe incompatibili":                                            $messaggio = "Unvertr&auml;gliche Tarife"; break;
-case "Importa i prezzi della":                                           $messaggio = "Preise importieren von"; break;
 case "dalla":                                                            $messaggio = "von"; break;
-case "aggiungendo":  				$messaggio = "adding"; break;
+case "aggiungendo":  				                         $messaggio = "und addieren"; break;
 case "I prezzi della tariffa selezionata sono stati importati":          $messaggio = "Die Preise des ausgew&auml;hlten Tarifs wurden importiert"; break;
 case "importa":                                                          $messaggio = "importieren"; break;
 case "se selezionato mantenere anche":                                   $messaggio = "wenn ausgew&auml;hlt au&szlig;erdem beibehalten"; break;
@@ -221,7 +212,6 @@ case "Aggiungi un bene":                                                 $messag
 case "Elimina un bene":                                                  $messaggio = "Artikel entfernen"; break;
 case "elimina i beni dall'inventario del magazzino":                     $messaggio = "Artikel l&ouml;schen nach Abrechnung des Lagers"; break;
 case "Beni dell'inventario da eliminare":                                $messaggio = "Artikelabrechnung zum l&ouml;schen"; break;
-case "Mostrare raggruppato con costi simili in inserimento":             $messaggio = "gleiche Kosten zusammenfassen"; break;
 case "Il tipo di applicazione della":                                    $messaggio = "Den Ausf&uuml;hrungstype w&auml;hlen"; break;
 case "per persona":                                                      $messaggio = "je Person"; break;
 case "per settimana":                                                    $messaggio = "je Woche"; break;
@@ -234,26 +224,86 @@ case "Le commissioni normali sulla":                                     $messag
 case "sono":                                                             $messaggio = "wird"; break;
 case "Inserisci o modifica le commissioni":                              $messaggio = "speichern der Nachl&auml;sse"; break;
 case "Tasse":                                                            $messaggio = "Steuern"; break;
-case "Tasse applicate sulla":                                            $messaggio = "Steuersatz &auml;ndern f&uuml;r"; break;
 case "della tariffa":                                                    $messaggio = "zum Satz von"; break;
 case "Inserisci o modifica le tasse":                                    $messaggio = "speichern der Steuern"; break;
-case "Le commissioni sono state modificate":                             $messaggio = "Kommission wurden ge&auml;ndert"; break;
+case "Le commissioni sono state modificate":                             $messaggio = "Kommissionen wurden ge&auml;ndert"; break;
 case "Le commissioni sono errate":                                       $messaggio = "Kommission sind falsch"; break;
 case "Le tasse sono state modificate":                                   $messaggio = "Steuern wurden ge&auml;ndert"; break;
 case "Le tasse sono errate":                                             $messaggio = "Steuern sind falsch"; break;
-case "tutti i prezzi delle tariffe si intendono con tasse già incluse":   $messaggio = "Alle genannten Preise beeinhalten Steuer"; break;
+case "tutti i prezzi delle tariffe si intendono con tasse già incluse":  $messaggio = "Alle genannten Preise beeinhalten Steuer"; break;
 case "Inserisci o modifica le commissioni normali":                      $messaggio = "Einf&uuml;gen und &auml;ndern der Kommission"; break;
 case "Inserisci o modifica le commissioni in questo periodo":            $messaggio = "Einf&uuml;gen und &auml;ndern der Kommission in der aktuellen Abrechnung"; break;
 case "Sulla":                                                            $messaggio = "Ein"; break;
 case "al giorno":                                                        $messaggio = "je Tag"; break;
 case "alla settimana":                                                   $messaggio = "je Woche"; break;
-case "il valore del costo si intente con tasse già incluse":            $messaggio = "Die Kosten beeinhalten die Steuer"; break;
+case "il valore del costo si intente con tasse già incluse":             $messaggio = "Die Kosten beeinhalten die Steuer"; break;
 case "Categoria":                                                        $messaggio = "Kategorie"; break;
-case "il prezzo della tariffa per i primi":  	$messaggio = "the rate price for the first"; break;
-case "il prezzo della tariffa per le prime":  	$messaggio = "the rate price for the first"; break;
-case "della":  					$messaggio = "of the"; break;
-case "tariffa + sconto":  			$messaggio = "rate + discount"; break;
-case "tariffa + sconto + costi agg.":  		$messaggio = "rate + discount + extra costs"; break;
+case "il prezzo della tariffa per i primi":  	$messaggio = "entspricht dem Normalpreis f&uuml;r die ersten"; break;
+case "il prezzo della tariffa per le prime":  	$messaggio = "entspricht dem Normalpreis f&uuml;r die ersten"; break;
+case "della":  					$messaggio = "vom"; break;
+case "tariffa + sconto":  			$messaggio = "Tarif + Rabatt"; break;
+case "tariffa + sconto + costi agg.":  		$messaggio = "Tarif + Rabatt + Extrageb&uuml;hren"; break;
+case "Nome della":  				$messaggio = "Name von"; break;
+case "Cambia":  				$messaggio = "&Auml;ndern"; break;
+case "prezzo per settimana":  			$messaggio = "Preis pro Woche"; break;
+case "prezzo per giorno":  			$messaggio = "Preis pro Tag"; break;
+case "prezzo per persona per settimana":  	$messaggio = "Preis pro Person und Woche"; break;
+case "prezzo per persona per giorno":  		$messaggio = "Preis pro Person und Tag"; break;
+case "p":  					$messaggio = "p"; break;
+case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Schnelles Einf&uuml;gen eines neuen Zuschlags f&uuml;r"; break;
+case "permanenza minima":  			$messaggio = "Mindestaufenthalt"; break;
+case "numero di bambini":  			$messaggio = "Anzahl Kinder"; break;
+case "letto aggiuntivo":  			$messaggio = "Zusatzbett"; break;
+case "offerta speciale":  			$messaggio = "Benutzerdefiniert"; break;
+case "inserisci":  				$messaggio = "Einf&uuml;gen"; break;
+case "Se":  					$messaggio = "If"; break;
+case "Se si inseriscono":  			$messaggio = "If"; break;
+case "Nessun dato è stato inserito":  		$messaggio = "No data has been inserted"; break;
+case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>finale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>single</b> extra cost"; break;
+case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>settimanale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>weekly</b> extra cost"; break;
+case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>giornaliero</b>":	$messaggio = "Choose the rates to which apply automatically the <b>daily</b> extra cost"; break;
+case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>percentuale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>percentage</b> extra cost"; break;
+case "se anche una sola settimana della prenotazione è all'interno dei periodi selezionati":	$messaggio = "if even only one week of the reservation is in the selected periods"; break;
+case "se anche un solo giorno della prenotazione è all'interno dei periodi selezionati":	$messaggio = "if even only one day of the reservation is in the selected periods"; break;
+case "Costo aggiuntivo già esistente":  	$messaggio = "Extra cost already inserted"; break;
+case "i prezzi della":  			$messaggio = "the prices to"; break;
+case "Mostrare raggruppato con costi simili della stessa categoria in inserimento":	$messaggio = "Display grouped with similar costs from same category in insertion"; break;
+case "Tasse applicate su":  			$messaggio = "Taxes applied on"; break;
+case "parte fissa della tariffa":  		$messaggio = "fixed part of the rate"; break;
+case "parte per una persona della tariffa":  	$messaggio = "one person part of the rate"; break;
+case "Numero massimo":  			$messaggio = "Maximum number"; break;
+case "0 se illimitato":  			$messaggio = "0 for unlimited"; break;
+case "meno":  					$messaggio = "minus"; break;
+case "il costo viene moltiplicato per zero se la somma è negativa":	$messaggio = "the cost will be multiplied by zero if the sum is negative"; break;
+case "Combina con altri costi":			$messaggio = "Combine with other costs"; break;
+case "i costi combinabili vengono mostrati tutti assieme con il nome della categoria ed ognuno è inserito se possibile":	$messaggio = "combined costs are shown all together with category name and each one is inserted when possible"; break;
+case "opzionale":  				$messaggio = "optional"; break;
+case "Costi combinati":  			$messaggio = "Combined costs"; break;
+case "Inserisci il costo aggiuntivo":  		$messaggio = "Insert the extra cost"; break;
+case "Numero minimo di giorni":  		$messaggio = "Minimum number of days"; break;
+case "Applicato alle tariffe":  		$messaggio = "Applied to rates"; break;
+case "Periodi in cui viene applicato il costo":	$messaggio = "Periods in which the cost is applied"; break;
+case "Valore dello sconto per ogni bambino":  	$messaggio = "Discount value for each child"; break;
+case "del prezzo di una persona":  		$messaggio = "of the price for one person"; break;
+case "solo per tariffe con prezzi a persona":  	$messaggio = "only for rates with per person prices"; break;
+case "con questo costo si deve includere il numero di bambini anche nel numero di persone":	$messaggio = "with this cost the number of children must be included in the number of people too"; break;
+case "Valore del letto aggiuntivo":  		$messaggio = "Value of the extra bed"; break;
+case "Valore dello sconto":  			$messaggio = "Discount value"; break;
+case "del prezzo totale":  			$messaggio = "of total price"; break;
+case "Se la prenotazione ha una durata di":	$messaggio = "If the reservation length is"; break;
+case "o più giorni":  				$messaggio = "days or more"; break;
+case "Importa ora":  				$messaggio = "Import now"; break;
+case "Importa sempre":  			$messaggio = "Always import"; break;
+case "cancella":  				$messaggio = "delete"; break;
+case "L'importatazione dei prezzi è stata cancellata":	$messaggio = "The prices import has been deleted"; break;
+case "al prezzo fisso":  			$messaggio = "to fixed price"; break;
+case "al prezzo per persona":  			$messaggio = "to per person price"; break;
+case "ad entrambi i prezzi":  			$messaggio = "to both prices"; break;
+case "La tariffa":  				$messaggio = "The rate"; break;
+case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo permanente":	$messaggio = "exports its prices to other rates, it can't import prices permanently"; break;
+case "tutte le tariffe":  			$messaggio = "all rates"; break;
+case "considerare l'intero costo come tasse":  	$messaggio = "consider the entire cost as taxes"; break;
+case "Escludere questo costo dal totale per altri costi percentuali":	$messaggio = "Exclude this cost from the total for other percentage costs"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
