@@ -31,7 +31,6 @@ case "Sconto":                                                           $messag
 case "Caparra":                                                          $messaggio = "Anzahlung"; break;
 case "resto":                                                            $messaggio = "Rest"; break;
 case "Ricalcola la caparra in base alla nuova tariffa":                  $messaggio = "Anzahlung automatisch errechnen"; break;
-case "Costo aggiuntivo unico":                                           $messaggio = "Single extra cost"; break;
 case "moltiplicato per":                                                 $messaggio = "multipliziert mit"; break;
 case "Costo aggiuntivo settimanale":                                     $messaggio = "w&ouml;chentliche Aufschl&auml;ge"; break;
 case "Costo aggiuntivo giornaliero":                                     $messaggio = "t&auml;gliche Aufschl&auml;ge"; break;
@@ -76,7 +75,6 @@ case "La data iniziale verrà cambiata dal":                             $messag
 case "al":                                                               $messaggio = "bis"; break;
 case "La data finale verrà cambiata dal":                               $messaggio = "Das Enddatum wird ge&auml;ndert von"; break;
 case "Le <div style=\"display: inline; color: red;\">date</div> sono <b>sbagliate</b>":        $messaggio = "Das gew&auml;hlte <div style=\"display: inline; color: red;\">Datum</div> ist <b>falsch</b>"; break;
-case "°</b> piano":                                                     $messaggio = "</b>"; break;
 case "della casa":                                                       $messaggio = "des Hauses"; break;
 case "con massimo numero di occupanti":                                  $messaggio = "mit der maximalen Personenzahl"; break;
 case "a":                                                                $messaggio = "zu"; break;
@@ -108,26 +106,26 @@ case "<b>superano</b> la durata della prenotazione":                     $messag
 case "verranno cabiate da":                                              $messaggio = "werden ge&auml;ndert von"; break;
 case "verranno cabiati da":                                              $messaggio = "wird ge&auml;ndert aus"; break;
 case "verranno cabiate":                                                 $messaggio = "wird ge&auml;ndert"; break;
-case "verranno cabiati":                                                 $messaggio = "wird ge&auml;ndert"; break;
-case "<b>non</b> verranno cambiate":                                     $messaggio = "werden <b>nicht</b> ge&auml;ndert"; break;
+case "verranno cabiati":                                                 $messaggio = "werden ge&auml;ndert"; break;
+case "<b>non</b> verranno cambiate":                                     $messaggio = "wird <b>nicht</b> ge&auml;ndert"; break;
 case "<b>non</b> verranno cambiati":                                     $messaggio = "werden <b>nicht</b> ge&auml;ndert"; break;
 case "su":                                                               $messaggio = "auf"; break;
 case "Il prezzo del costo aggiuntivo":                                   $messaggio = "Der Preis der Extra-Geb&uuml;hren"; break;
 case "verrà tolto":                                                     $messaggio = "werden gel&ouml;scht"; break;
-case "I dati del costo aggiuntivo <b>straordinario</b> sono <div style=\"display: inline; color: red;\">errati o mancanti</div>":        $messaggio = "Data for the <b>extraordinary</b> extra cost are <div style=\"display: inline; color: red;\">wrong or lacking</div>"; break;
+case "I dati del costo aggiuntivo <b>straordinario</b> sono <div style=\"display: inline; color: red;\">errati o mancanti</div>":        $messaggio = "Die Daten f&uuml;r <b>au&szlig;ergew&ouml;hnliche</b> Extra-Geb&uuml;hren <div style=\"display: inline; color: red;\">fehlen oder sind fehlerhaft</div>"; break;
 case "verrà aggiunto":                                                  $messaggio = "werden hinzugef&uuml;gt"; break;
 case "come letto aggiuntivo":                                            $messaggio = "als Zusatzbett"; break;
 case "Le settimane del nuovo costo aggiuntivo":                          $messaggio = "Die Wochen der neuen Aufschl&auml;ge"; break;
 case "I giorni del nuovo costo aggiuntivo":                              $messaggio = "Die Tage der neuen Aufschl&auml;ge"; break;
-case "Lo <div style=\"display: inline; color: red;\">sconto</div> inserito":        $messaggio = "The inserted <div style=\"display: inline; color: red;\">discount</div>"; break;
+case "Lo <div style=\"display: inline; color: red;\">sconto</div> inserito":        $messaggio = "Der eingegebene <div style=\"display: inline; color: red;\">Rabatt</div>"; break;
 case "supera il costo totale senza sconto":                              $messaggio = "ist gr&ouml;&szlig;er als die gesamten Kosten ohne Rabatt"; break;
 case "Lo sconto verrà cambiato da":                                     $messaggio = "Der Rabatt wird ge&auml;ndert von"; break;
-case "La <div style=\"display: inline; color: red;\">caparra</div> inserita":        $messaggio = "The inserted <div style=\"display: inline; color: red;\">deposit</div>"; break;
+case "La <div style=\"display: inline; color: red;\">caparra</div> inserita":        $messaggio = "Die eingegebene<div style=\"display: inline; color: red;\">Anzahlung</div>"; break;
 case "supera il costo totale":                                           $messaggio = "ist gr&ouml;&szlig;er als die gesamten Kosten"; break;
 case "La caparra verrà cambiata da":                                    $messaggio = "Die Anzahlung wird ge&auml;ndert von"; break;
-case "La <div style=\"display: inline; color: red;\">caparra</div>":     $messaggio = "The <div style=\"display: inline; color: red;\">deposit</div>"; break;
+case "La <div style=\"display: inline; color: red;\">caparra</div>":     $messaggio = "Die <div style=\"display: inline; color: red;\">Anzahlung</div>"; break;
 case "supera il nuovo costo totale":                                     $messaggio = "ist gr&ouml;&szlig;er als die neuen kompletten Kosten"; break;
-case "La cifra <div style=\"display: inline; color: red;\">pagata</div> inserita":        $messaggio = "The inserted <div style=\"display: inline; color: red;\">paid</div> amount"; break;
+case "La cifra <div style=\"display: inline; color: red;\">pagata</div> inserita":        $messaggio = "Der eingegebene <div style=\"display: inline; color: red;\">Zahlungs</div>betrag"; break;
 case "I soldi pagati verranno cambiati da":                              $messaggio = "Der gezahlte Betrag wird ge&auml;ndert auf"; break;
 case "verrà <b>confermata</b>":                                         $messaggio = "wird <b>best&auml;tigt</b>"; break;
 case "Verrà tolta la <b>conferma</b> alla prenotazione":                $messaggio = "Die <b>Best&auml;tigung</b> wird aus der Reservierung gel&ouml;scht"; break;
@@ -145,47 +143,32 @@ case "Inserita dall'utente":                                             $messag
 case "Si considererà l'utente":                                         $messaggio = "Benutzer"; break;
 case "come colui che ha inserito la prenotazione":                       $messaggio = "wird eingetragen als der der die Reservierung eingetragen hat"; break;
 case "Non si possono inserire altri costi":                              $messaggio = "Sie k&ouml;nnen keine weiteren Geb&uuml;hren erfassen"; break;
-case "in questo periodo, già":                                          $messaggio = "in this period, already"; break;
-case "presenti":                                                         $messaggio = "present"; break;
+case "in questo periodo, già":                                          $messaggio = "in dieser Periode"; break;
+case "presenti":                                                         $messaggio = "derzeit"; break;
 case "Non si puo inserire il costo aggiuntivo":                          $messaggio = "Die Extra-Geb&uuml;hren"; break;
 case "in questo periodo":                                                $messaggio = "kann im Zeitraum nicht eingef&uuml;gt werden"; break;
-case "Settimane":                                                        $messaggio = "Weochen"; break;
+case "Settimane":                                                        $messaggio = "Wochen"; break;
 case "Giorni":                                                           $messaggio = "Tage"; break;
 case "mostra":                                                           $messaggio = "anzeigen"; break;
 case "nascondi":                                                         $messaggio = "verstecken"; break;
 case "numeri diversi":                                                   $messaggio = "verschiedene Nummern"; break;
-case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":        $messaggio = "You can't insert more than one extra cost with percentage on total price per reservation"; break;
-case "Scegliere le settimane in cui applicare il costo aggiuntivo":      $messaggio = "Choose the weeks to be applied for the extra cost"; break;
-case "Scegliere i giorni in cui applicare il costo aggiuntivo":          $messaggio = "Choose the days to be applied for the extra cost"; break;
-case "Si deve inserire il numero delle persone per il costo aggiuntivo":        $messaggio = "The number of people must be inserted for the extra cost"; break;
+case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":        $messaggio = "Sie k&ouml;nnen nicht mehr als eine Extra-Geb&uuml;hr einf&uuml;gen, die prozentual vom Gesamtpreis berechnet wird"; break;
+case "Scegliere le settimane in cui applicare il costo aggiuntivo":      $messaggio = "Die Wochen ausw&auml;hlen, f&uuml;r die die Extra-Geb&uuml;hr angewendet werden sollen"; break;
+case "Scegliere i giorni in cui applicare il costo aggiuntivo":          $messaggio = "Die Tage ausw&auml;hlen, f&uuml;r die die Extra-Geb&uuml;hr angewendet werden sollen."; break;
+case "Si deve inserire il numero delle persone per il costo aggiuntivo": $messaggio = "F&uuml;r diese Extra-Geb&uuml;hr ist die Anzahl der G&auml;ste n&ouml;tig"; break;
 case "Non si possono inserire altri costi":                              $messaggio = "Sie k&ouml;nnen keine weiteren Geb&uuml;hren erfassen"; break;
-case "in questo periodo, già":                                          $messaggio = "in this period, already"; break;
-case "presenti":                                                         $messaggio = "present"; break;
-case "della tariffa":                                                    $messaggio = "of rate"; break;
-case "del totale":                                                       $messaggio = "of total"; break;
-case "della caparra":                                                    $messaggio = "of deposit"; break;
-case "del resto caparra":                                                $messaggio = "of deposit rest"; break;
-case "di base":                                                          $messaggio = "of base"; break;
+case "in questo periodo, già":                                          $messaggio = "in dieser Periode"; break;
+case "presenti":                                                         $messaggio = "derzeit"; break;
 case "totale":                                                           $messaggio = "Summe"; break;
 case "registra entrata":                                                 $messaggio = "CheckIn"; break;
 case "cancella entrata":                                                 $messaggio = "l&ouml;sche CheckIn"; break;
 case "registra uscita":                                                  $messaggio = "CheckOut"; break;
 case "cancella uscita":                                                  $messaggio = "l&ouml;sche CheckOut"; break;
-case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata già registrato":        $messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-in already registered"; break;
-case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata non registrato":        $messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-in not registered"; break;
-case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita già registrato":        $messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-out already registered"; break;
-case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita non registrato, registrare prima l'entrata":        $messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-out not registered, register check-in before"; break;
 case "Metodo pagamento caparra":                                         $messaggio = "Anzahlungsart"; break;
 case "Il metodo di pagamento della caparra verrà cambiato a":           $messaggio = "Anzahlungsart wurde ge&auml;ndert auf"; break;
 case "Metodo di pagamento":                                              $messaggio = "Zahlungsart"; break;
 case "metodo di pagamento":                                              $messaggio = "Zahlart"; break;
-case "Normalmente le prenotazioni già iniziate e quelle che hanno registrato l'orario di entrata non vengono spostate":        $messaggio = "Normally already begun reservations and the ones that have done check-in are not moved"; break;
 case "Prova di nuovo":                                                   $messaggio = "Bitte neu versuchen"; break;
-case "muovendo anche le prenotazioni iniziate dopo il":                  $messaggio = "moving also reservations begun after"; break;
-case "considerate fisse perchè <div style=\"display: inline; color: red;\">ad oggi già iniziate</div>":        $messaggio = "considered fixed because <div style=\"display: inline; color: red;\">as of today already begun</div>"; break;
-case "è incompatibile con la tariffa selezionata":                      $messaggio = "is incompatible with selected rate"; break;
-case "non può essere applicato":                                        $messaggio = "can't be applied"; break;
-case "Non si può cambiare l'assegnazione di una prenotazione che si trova <div style=\"display: inline; color: red;\">tra due anni</div>":        $messaggio = "You can't change the assignment of a reservation that is <div style=\"display: inline; color: red;\">between two years</div>"; break;
 case "Modifica nell'anno precedente":                                    $messaggio = "&Auml;nderungen im vergangenen Jahr"; break;
 case "Orario entrata stimato":                                           $messaggio = "gew&uuml;nschte CheckIn Zeit"; break;
 case "L'orario stimato di entrata verrà cambiato a":                    $messaggio = "Die gew&uuml;nschte CheckIn Zeit wurde ge&auml;ndert auf"; break;
@@ -194,7 +177,7 @@ case "rigenera":                                                         $messag
 case "Non si è potuto spostare la prenotazione per la registrazione dell'entrata":        $messaggio = "Es ist nicht m&ouml;glich die Buchung w&auml;hrend des CheckIn zu ver&auml;ndern"; break;
 case "Cambia cliente":                                                   $messaggio = "Gast &auml;ndern"; break;
 case "Nuovo titolare della prenotazione":                                $messaggio = "Neuer Ansprechpartner zur Buchung"; break;
-case "cliente numero":                                                   $messaggio = "client number"; break;
+case "cliente numero":                                                   $messaggio = "Kundennummer"; break;
 case "Il titolare della prenotazione":                                   $messaggio = "der Ansprechpartner der Buchung"; break;
 case "Il titolare delle prenotazioni":                                   $messaggio = "der Titel der Buchungen"; break;
 case "Cliente non trovato":                                              $messaggio = "Gast nicht gefunden"; break;
@@ -219,14 +202,7 @@ case "Cancella le prenotazioni":                                         $messag
 case "della prenotazione":                                               $messaggio = "aus Buchung"; break;
 case "per la prenotazione":                                              $messaggio = "f&uuml;r Buchung"; break;
 case "Data inserimento":                                                 $messaggio = "Erfasssungsdatum"; break;
-case "con i costi aggiuntivi selezionati":                               $messaggio = "with selected extra costs"; break;
-case "I beni richiesti dal costo":                                       $messaggio = "Goods needed by cost"; break;
-case "non sono disponibili nell'inventario":                             $messaggio = "are not available in the inventory"; break;
-case "<b><big>i</big></b>":                                              $messaggio = "<b><big>i</big></b>"; break;
-case "pren.":                                                            $messaggio = "res."; break;
-case "Si deve inserire il <span class=\"colred\">numero delle persone</span> per la tariffa selezionata":        $messaggio = "The <span class=\"colred\">number of people</span> must be inserted for the selected rate"; break;
 case "Partita iva":                                                      $messaggio = "UstId."; break;
-case "i beni richiesti alla registrazione dell'entrata":                 $messaggio = "items needed by check-in"; break;
 case "Commissioni":                                                      $messaggio = "Nachl&auml;sse"; break;
 case "Ricalcola le commissioni in base alla nuova tariffa":              $messaggio = "Nachl&auml;sse automatisch zum Tarif berechnen"; break;
 case "Le commissioni verranno cambiate da":                              $messaggio = "Nachl&auml;sse werden ge&auml;ndert von"; break;
@@ -239,6 +215,40 @@ case "Attenzione":                                                       $messag
 case "vi sono altre prenotazioni dello stesso cliente nello stesso periodo che ancora non sono state pagate":        $messaggio = "es sind weitere Buchungen im selben Zeitraum des Gastes vorhanden, die noch nicht bezahlt sind"; break;
 case "Il saldo totale pagato sarà di":                                  $messaggio = "Der Gesamtbetrag bel&auml;uft sich auf"; break;
 case "ln.":  					$messaggio = "ln."; break;
+case "Costo aggiuntivo unico":  		$messaggio = "Single extra cost"; break;
+case "°</b> piano":  				$messaggio = "</b>"; break;
+case "della tariffa":  				$messaggio = "of rate"; break;
+case "del totale":  				$messaggio = "of total"; break;
+case "della caparra":  				$messaggio = "of deposit"; break;
+case "del resto caparra":  			$messaggio = "of deposit rest"; break;
+case "di base":  				$messaggio = "of base"; break;
+case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-in already registered"; break;
+case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata non registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-in not registered"; break;
+case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-out already registered"; break;
+case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita non registrato, registrare prima l'entrata":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-out not registered, register check-in before"; break;
+case "Normalmente le prenotazioni già iniziate e quelle che hanno registrato l'orario di entrata non vengono spostate":	$messaggio = "Normally already begun reservations and the ones that have done check-in are not moved"; break;
+case "muovendo anche le prenotazioni iniziate dopo il":	$messaggio = "moving also reservations begun after"; break;
+case "considerate fisse perchè <div style=\"display: inline; color: red;\">ad oggi già iniziate</div>":	$messaggio = "considered fixed because <div style=\"display: inline; color: red;\">as of today already begun</div>"; break;
+case "è incompatibile con la tariffa selezionata":	$messaggio = "is incompatible with selected rate"; break;
+case "non può essere applicato":  		$messaggio = "can't be applied"; break;
+case "Non si può cambiare l'assegnazione di una prenotazione che si trova <div style=\"display: inline; color: red;\">tra due anni</div>":	$messaggio = "You can't change the assignment of a reservation that is <div style=\"display: inline; color: red;\">between two years</div>"; break;
+case "con i costi aggiuntivi selezionati":  	$messaggio = "with selected extra costs"; break;
+case "I beni richiesti dal costo":  		$messaggio = "Goods needed by cost"; break;
+case "non sono disponibili nell'inventario":  	$messaggio = "are not available in the inventory"; break;
+case "<b><big>i</big></b>":  			$messaggio = "<b><big>i</big></b>"; break;
+case "pren.":  					$messaggio = "res."; break;
+case "Si deve inserire il <span class=\"colred\">numero delle persone</span> per la tariffa selezionata":	$messaggio = "The <span class=\"colred\">number of people</span> must be inserted for the selected rate"; break;
+case "i beni richiesti alla registrazione dell'entrata":	$messaggio = "items needed by check-in"; break;
+case "della tariffa fissa":  			$messaggio = "of fixed rate"; break;
+case "di una persona":  			$messaggio = "of one person"; break;
+case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
+case "Nuovo costo aggiuntivo":  		$messaggio = "New extra cost"; break;
+case "aggiungi promemoria per l'entrata":  	$messaggio = "add a reminder for checkin"; break;
+case "aggiungi promemoria per l'uscita":  	$messaggio = "add a reminder for checkout"; break;
+case "Verrà aggiunto un <b>promemoria</b> per l'<em>entrata</em>":	$messaggio = "A <b>reminder</b> for <em>checkin</em> will be added"; break;
+case "Verrà aggiunto un <b>promemoria</b> per l'<em>uscita</em>":	$messaggio = "A <b>reminder</b> for <em>checkout</em> will be added"; break;
+case "Promemoria":  				$messaggio = "Reminder"; break;
+case "La <b>tariffa</b> richiesta è <span class=\"colred\">chiusa</span> in questo periodo":	$messaggio = "The requested <b>rate</b> is <span class=\"colred\">closed</span> in this period"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
