@@ -27,7 +27,6 @@ case "Costo_gio.":                                       $messaggio = "t&auml;gl
 case "Soldi di prenotazioni cancellate":                 $messaggio = "Geld aus gel&ouml;schten Buchungen"; break;
 case "TOTALE":                                           $messaggio = "<b>Summe</b>"; break;
 case "Trasferito in cassa":                              $messaggio = "In die Kasse &uuml;bertragen"; break;
-case "RESTO":                                            $messaggio = "REST"; break;
 case "Sei sicuro di voler cancellare la spesa":          $messaggio = "Wollen Sie den Zahlungsausgang wirklich l&ouml;schen?"; break;
 case "del valore di":                                    $messaggio = "im Wert von"; break;
 case "Sei sicuro di voler cancellare l'entrata":         $messaggio = "Wollen Sie den Zahlungseingang wirklich l&ouml;schen?"; break;
@@ -36,14 +35,14 @@ case "NO":                                               $messaggio = "NEIN"; br
 case "Entrata o spesa":                                  $messaggio = "Zahlungseingang oder Zahlungsausgang"; break;
 case "cacellata":                                        $messaggio = "gel&ouml;scht"; break;
 case "Costo o spesa già cancellati":                    $messaggio = "Zahlungseingang oder Zahlungsausgang bereits gel&ouml;scht"; break;
-case "Tutte le spese del":  			$messaggio = "All expenses of"; break;
-case "nella cassa principale":  		$messaggio = "in main cashbox"; break;
+case "Tutte le spese del":  			         $messaggio = "Alle Ausgaben aus "; break;
+case "nella cassa principale":  		         $messaggio = "(Hauptkasse)"; break;
 case "Natura_spesa":                                     $messaggio = "Zahlungsgrund"; break;
 case "Importo":                                          $messaggio = "Wert"; break;
 case "Inserita_da":                                      $messaggio = "eingetragen_von"; break;
 case "Data_di_inserimento":                              $messaggio = "Eintragungsdatum"; break;
-case "Cancella":                                         $messaggio = "Aktion"; break;
-case "Tutte le entrate del":  			$messaggio = "All incomes of"; break;
+case "Cancella":                                         $messaggio = "L&ouml;schen"; break;
+case "Tutte le entrate del":  			         $messaggio = "Alle Einnahmen aus"; break;
 case "Natura_entrata":                                   $messaggio = "Grund_f&uuml;r_Eingang"; break;
 case "cancella":                                         $messaggio = "l&ouml;schen"; break;
 case "entrata presa dalle prenotazioni":                 $messaggio = "Eingang von den Reservierungen abziehen"; break;
@@ -51,11 +50,11 @@ case "Inserisci nuove spese o entrate":                  $messaggio = "Neue Eing
 case "Storia entrate-uscite prenotazioni":               $messaggio = "Verlauf der Reservierungszahlungen"; break;
 case "Sei sicuro di voler cancellare il costo aggiuntivo":        $messaggio = "Zuschl&auml;ge wirklich l&ouml;schen?"; break;
 case "Il costo aggiuntivo":                              $messaggio = "Die Zuschl&auml;ge"; break;
-case "Il costo aggiuntivo è cambiato nel frattempo, non è stato cancellato":        $messaggio = "Die Extrakosten wurden ge&auml;ndert NICHT gel&ouml;scht"; break;
+case "Il costo aggiuntivo è cambiato nel frattempo, non è stato cancellato":        $messaggio = "Die Extrageb&uuml;hren wurden ge&auml;ndert NICHT gel&ouml;scht"; break;
 case "è stato cancellato":                              $messaggio = "wurden gel&ouml;scht"; break;
 case "I periodi sono stati aggiunti fino al":            $messaggio = "Zeitr&auml;ume wurden hinzugef&uuml;gt bis"; break;
 case "Tabella con periodi e relative tariffe del":       $messaggio = "Tarif&uuml;bersicht f&uuml;r"; break;
-case "tariffa":                                          $messaggio = "Tarifno. "; break;
+case "tariffa":                                          $messaggio = "Tarif Nr. "; break;
 case "Inizio_settimana":                                 $messaggio = "Wochenanfang"; break;
 case "Inizio_giorno":                                    $messaggio = "Starttag"; break;
 case "Fine_settimana":                                   $messaggio = "Wochenende"; break;
@@ -63,7 +62,6 @@ case "Fine_giorno":                                      $messaggio = "Endtag";
 case "Aggiungi periodi":                                 $messaggio = "Zeitr&auml;ume hinzuf&uuml;gen"; break;
 case "fino al mese":                                     $messaggio = "bis Monat"; break;
 case "Tabella con i costi aggiuntivi del":               $messaggio = "Zuschl&auml;ge f&uumlr"; break;
-case "Nome":                                             $messaggio = "Name"; break;
 case "Tipo":                                             $messaggio = "Art"; break;
 case "Prezzo":                                           $messaggio = "Wert"; break;
 case "Da_assegnare":                                     $messaggio = "verbinden_mit"; break;
@@ -85,7 +83,7 @@ case "con_n°_di_settimane":                             $messaggio = "frage_nac
 case "con_n°_di_giorni":                                $messaggio = "frage_nach_der_Anzahl der Tage"; break;
 case "_da_chiedere":                                     $messaggio = "..."; break;
 case "percentuale":                                      $messaggio = "Prozentsatz"; break;
-case "% arrotondato_a_":                                 $messaggio = "% gerunden_auf_"; break;
+case "% arrotondato_a_":                                 $messaggio = "% gerundet_auf_"; break;
 case "Caparre, commissioni e tasse del":                 $messaggio = "Anzahlung-, Rabatt- und Steuers&auml;tze f&uuml;r"; break;
 case "Arrotondato_a":                                    $messaggio = "gerundet auf"; break;
 case "Vai alla pagina di inserzione prezzi":             $messaggio = "Zur Preiseingabeseite"; break;
@@ -95,7 +93,6 @@ case "Tabella con tutti i clienti":                      $messaggio = "G&auml;st
 case "pag. prec.":                                       $messaggio = "zur&uuml;ck"; break;
 case "pag. succ.":                                       $messaggio = "weiter"; break;
 case "Cognome":                                          $messaggio = "Nachname"; break;
-case "Nome":                                             $messaggio = "Name"; break;
 case "Telefono":                                         $messaggio = "Telefon"; break;
 case "Indirizzo":                                        $messaggio = "Addresse"; break;
 case "Città":                                           $messaggio = "Stadt"; break;
@@ -107,6 +104,8 @@ case "Data_di_nascita":                                  $messaggio = "Geburtsta
 case "2°telefono":                                      $messaggio = "2. Telefon"; break;
 case "Commento":                                         $messaggio = "Kommentar"; break;
 case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 2 per la":        $messaggio = "Zuweisung Regel 2 wirklich <b>l&ouml;schen</b> f&uuml;r"; break;
+case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":        $messaggio = "Sind sie sicher, da&szlig; Sie die Zuweisungsregel 3 <b>l&ouml;schen</b> wollen f&uuml;r"; break;
+case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":        $messaggio = "Wollen Sie wirklich die <b>Regel Nr. 4 l&ouml;schen</b> "; break;
 case "La regola di assegnazione è stata cancellata":    $messaggio = "Zuweisungsregel gel&ouml;scht"; break;
 case "La regola di assegnazione è già stata cancellata":        $messaggio = "Die Zuweisungsregel wurde bereits gel&ouml;scht"; break;
 case "Tabella con le regole di assegnazione 1 del":      $messaggio = "Regel 1. Fragen bei Zuteilung"; break;
@@ -155,7 +154,6 @@ case "selezionate precedentemente":                      $messaggio = "wie ausge
 case "Saldo totale":                                     $messaggio = "Differenz gesamt"; break;
 case "l'anno":                                           $messaggio = "Jahr"; break;
 case "dal database":                                     $messaggio = "aus der Datenbank"; break;
-case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, tutti i dati riguardanti l'anno":	$messaggio = "<b style=\"color: red;\">WARNING</b>: if you press <b>\"<i>Continue</i>\"</b>, all data regarding year"; break;
 case "verranno <b>cancellati</b>":                       $messaggio = "<b>gel&ouml;scht</b>"; break;
 case "L'anno":                                           $messaggio = "Jahr"; break;
 case "è stato cancellato dal batabase":                 $messaggio = "wurde aus der Datenbank gel&ouml;scht"; break;
@@ -166,7 +164,6 @@ case "Cliente":                                          $messaggio = "Kunde"; b
 case "cliente":                                          $messaggio = "Kunde"; break;
 case "Tabella con le regole di assegnazione 3 del":      $messaggio = "Regel 3. Admin->Benutzer"; break;
 case "Utente":                                           $messaggio = "Benutzer"; break;
-case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":        $messaggio = "Sind sie sicher, daß sie die Zuweisungsregel 3 <b>l&ouml;schen</b> wollen f&uuml;r"; break;
 case "Periodi_permessi":                                 $messaggio = "zugewiesene_Zeitr&auml;ume"; break;
 case "unico":                                            $messaggio = "einmalig"; break;
 case "fisso":                                            $messaggio = "fest"; break;
@@ -187,8 +184,6 @@ case "_nella_stessa_settimana":                          $messaggio = "_in_der_g
 case "_nello_stesso_giorno":                             $messaggio = "_am_gleichen_Tag"; break;
 case "Prenotazione intera in":                           $messaggio = "Gesamte Reservierung"; break;
 case "Parte della prentoazione in":                      $messaggio = "Teil der Resrvierung in"; break;
-case "Solo settimane della prenotazione in":             $messaggio = "Only weeks of reservation in"; break;
-case "Solo giorni della prenotazione in":                $messaggio = "Only days of reservation in"; break;
 case " o ":                                              $messaggio = " oder "; break;
 case " a ":                                              $messaggio = " bis "; break;
 case "_si":                                              $messaggio = "_ja"; break;
@@ -205,19 +200,18 @@ case "Cancellati":                                       $messaggio = "Gel&ouml;
 case "clienti":                                          $messaggio = "G&auml;ste"; break;
 case "OK":                                               $messaggio = "OK"; break;
 case "Annulla":                                          $messaggio = "Abbrechen"; break;
-case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>cancellare":        $messaggio = "Are you sure you want to <div style=\"display: inline; color: red;\"><b>delete"; break;
-case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun pagamento":        $messaggio = "clients</b></div> that don't have any associated reservation or payment"; break;
+case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>cancellare":        $messaggio = "Wollen Sie wirklich <div style=\"display: inline; color: red;\"><b>l&ouml;schen"; break;
+case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun pagamento":        $messaggio = "Kunden</b></div> ohne zugeordnete Reservierung oder Zahlung"; break;
 case "Cancella i clienti senza prenotazioni":            $messaggio = "G&auml;ste ohne Reservierung l&ouml;schen"; break;
 case "Metodo pagamento":                                 $messaggio = "Zahlungsweise"; break;
-case "Tariffe":                                          $messaggio = "Tarifno."; break;
+case "Tariffe":                                          $messaggio = "Tarif-Nr."; break;
 case "del":                                              $messaggio = "in"; break;
 case "Modifica tutti i campi della tabella":             $messaggio = "Direkt&auml;nderung in der Tabelle"; break;
 case "Modifica i campi della tabella":                   $messaggio = "Direkt&auml;nderung in der Tabelle"; break;
-case "Applica i cambiamenti":                            $messaggio = "nderungen &uuml;bernehmen"; break;
+case "Applica i cambiamenti":                            $messaggio = "&Auml;nderungen &uuml;bernehmen"; break;
 case "documento di tipo":                                $messaggio = "Dokumente"; break;
 case "visualizza":                                       $messaggio = "erstellen"; break;
 case "Vedi tutte le prenotazioni":                       $messaggio = "Alle Reservierungen betrachten"; break;
-case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":        $messaggio = "Wollen Sie wirklich die <b>Regel No. 4 l&ouml;schen</b> "; break;
 case "Tabella con le regole di assegnazione 4 del":      $messaggio = "Zuweisung 4. Tarif->G&auml;steanzahl"; break;
 case "Numero di persone":                                $messaggio = "Personenanzahl"; break;
 case "assegna_se_":                                      $messaggio = "zuweisen_sobald_"; break;
@@ -246,17 +240,17 @@ case "Statistiche":                                      $messaggio = "Statistik
 case "Anni":                                             $messaggio = "Jahre"; break;
 case "Numero di prenotazioni per mese":                  $messaggio = "Anzahl der Buchungen per Monat"; break;
 case "Entrate dalle prenotazioni per mese":              $messaggio = "eingegangene Reservierungen je Monat"; break;
-case "Entrate progressive dalle prenotazioni":           $messaggio = "Einkommen aus Progressive-Hotelreservierungen"; break;
+case "Entrate progressive dalle prenotazioni":           $messaggio = "Umsatz aus Reservierungen (kumulativ)"; break;
 case "Numero di prenotazioni per origine":               $messaggio = "Anzahl Reservierungen pro Herkunft"; break;
 case "Entrate dalle prenotazioni per origine":           $messaggio = "Einkommen von Reservierungen pro Herkunft"; break;
-case "Cambia":                                           $messaggio = "Ver&auml;nderung"; break;
+case "Cambia":                                           $messaggio = "&Auml;ndern"; break;
 case "Mesi":                                             $messaggio = "Monate"; break;
 case "Entrate per metodo di pagamento":                  $messaggio = "Einnahmen je Zahlungsart"; break;
 case "Descrizione":                                      $messaggio = "Beschreibung"; break;
 case "magazzino":                                        $messaggio = "Lager"; break;
 case "inventario":                                       $messaggio = "Bestand"; break;
 case "aggiungi":                                         $messaggio = "hinzuf&uuml;gen"; break;
-case "Codice":                                           $messaggio = "Art.No"; break;
+case "Codice":                                           $messaggio = "Art.-Nr"; break;
 case "Beni inventario":                                  $messaggio = "Vorr&auml;te"; break;
 case "Mancanti":                                         $messaggio = "Fehlbestand"; break;
 case "bene eliminato":                                   $messaggio = "Artikel gel&ouml;scht"; break;
@@ -269,7 +263,6 @@ case "dal magazzino":                                    $messaggio = "aus Lager
 case "Incompatibilità":                                 $messaggio = "Ausschl&uuml;sse"; break;
 case "raggruppa":                                        $messaggio = "Gruppe"; break;
 case "con email":                                        $messaggio = "mit eMail:"; break;
-case "Importa":                                          $messaggio = "Import"; break;
 case "per persona":                                      $messaggio = "je Person"; break;
 case "con meno di":                                      $messaggio = "weniger als"; break;
 case "dall'inizio":                                      $messaggio = "von Start"; break;
@@ -303,34 +296,67 @@ case "Documenti_salvati":                                $messaggio = "gespeiche
 case "TASSE":                                            $messaggio = "Steuern"; break;
 case "resto":                                            $messaggio = "offen"; break;
 case "cancella_periodi":                                 $messaggio = "gel&ouml;schte_Perioden"; break;
-case "Sei sicuro di voler cancellare le commissioni dal":        $messaggio = "Are you sure you want to delete commissions from"; break;
 case "sulla tariffa":                                    $messaggio = "Durchschnitt"; break;
 case "Le commissioni sono state cancellate":             $messaggio = "Rabatte wurden gel&ouml;scht"; break;
 case "Le commissioni sono cambiate nel frattempo, non sono state cancellate":        $messaggio = "Rabatte wurden ge&auml;ndert, nicht gel&ouml;scht"; break;
-case "giorno":  				$messaggio = "day"; break;
-case "settimana":  				$messaggio = "week"; break;
+case "giorno":  				$messaggio = "Tag"; break;
+case "settimana":  				$messaggio = "Woche"; break;
+case "sconto":  				$messaggio = "Rabatt"; break;
+case "Numero di prenotazioni per nazionalità del cliente titolare":	$messaggio = "Anzahl Reservierungen nach Nationalit&auml;t"; break;
+case "Entrate dalle prenotazioni per nazionalità del cliente titolare":	$messaggio = "Umsatz aus Reservierungen nach Nationalit&auml;t"; break;
+case "Prezzi con":  				$messaggio = "Preise mit"; break;
+case "Prenotazioni anno corrente":  		$messaggio = "Reservierungen des aktuellen Jahres"; break;
+case "con prenotazioni inserite":  		$messaggio = "Mit Reservierungen"; break;
+case "fino al":  				$messaggio = "bis"; break;
+case "nella cassa chiamata":  			$messaggio = "in der Kasse"; break;
+case "Totale nella cassa principale":  		$messaggio = "Summe in Hauptkasse"; break;
+case "Totale nella cassa":  			$messaggio = "Summe in Kasse"; break;
+case "Nuova cassa chiamata":  			$messaggio = "Neue Kasse namens"; break;
+case "Crea":  					$messaggio = "Anlegen"; break;
+case "Una cassa chiamata":  			$messaggio = "Eine Kasse namens"; break;
+case "è stata creata":  			$messaggio = "wurde angelegt"; break;
+case "Cassa chiamata":  			$messaggio = "Kasse namens"; break;
+case "La cassa chiamata":  			$messaggio = "Die Kasse namens"; break;
+case "è stata cancellata":  			$messaggio = "wurde gel&ouml;scht"; break;
+case "Eventuali entrate e spese presenti in cassa non sono state cancellate":	$messaggio = "Einige Einnahmen und Ausgaben in dieser Kasse wurden nicht gel&ouml;scht"; break;
+case "Modifica i beni già inseriti":  		$messaggio = "Bereits eingef&uuml;gte Eintr&auml;ge &auml;ndern"; break;
+case "Modifica i beni":  			$messaggio = "Eintrag &auml;ndern"; break;
+case "I beni sono stati modificati":  		$messaggio = "Die Eintr&auml;ge wurden ver&auml;ndert"; break;
+case "p":  					$messaggio = "p"; break;
+case "password errata":  			$messaggio = "falsche Kennwort"; break;
+case "Aggiungi":  				$messaggio = "Add"; break;
+case "RESTO":  					$messaggio = "REST"; break;
+case "Nome":  					$messaggio = "Name"; break;
+case "Nome":  					$messaggio = "Name"; break;
+case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 1 for"; break;
+case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, tutti i dati riguardanti l'anno":	$messaggio = "<b style=\"color: red;\">WARNING</b>: if you press <b>\"<i>Continue</i>\"</b>, all data regarding year"; break;
+case "Solo settimane della prenotazione in":  	$messaggio = "Only weeks of reservation in"; break;
+case "Solo giorni della prenotazione in":  	$messaggio = "Only days of reservation in"; break;
+case "Importa":  				$messaggio = "Import"; break;
+case "Sei sicuro di voler cancellare le commissioni dal":	$messaggio = "Are you sure you want to delete commissions from"; break;
 case "costi agg.":  				$messaggio = "extra costs"; break;
-case "sconto":  				$messaggio = "discount"; break;
-case "Numero di prenotazioni per nazionalità del cliente titolare":	$messaggio = "Number of reservations per nationality of titular client"; break;
-case "Entrate dalle prenotazioni per nazionalità del cliente titolare":	$messaggio = "Incomes from reservations per nationality of titular client"; break;
-case "Prezzi con":  				$messaggio = "Prices with"; break;
-case "Prenotazioni anno corrente":  		$messaggio = "Current year reservations"; break;
-case "con prenotazioni inserite":  		$messaggio = "with reservations inserted"; break;
-case "fino al":  				$messaggio = "until"; break;
-case "nella cassa chiamata":  			$messaggio = "in the cashbox called"; break;
-case "Totale nella cassa principale":  		$messaggio = "Total in main cashbox"; break;
-case "Totale nella cassa":  			$messaggio = "Total in cashbox"; break;
-case "Nuova cassa chiamata":  			$messaggio = "New cashbox called"; break;
-case "Crea":  					$messaggio = "Create it"; break;
-case "Una cassa chiamata":  			$messaggio = "A cashbox called"; break;
-case "è stata creata":  			$messaggio = "has been created"; break;
-case "Cassa chiamata":  			$messaggio = "Cashbox called"; break;
-case "La cassa chiamata":  			$messaggio = "The cashbox called"; break;
-case "è stata cancellata":  			$messaggio = "has been deleted"; break;
-case "Eventuali entrate e spese presenti in cassa non sono state cancellate":	$messaggio = "Any incomes and expenses present in this cashbox have not been deleted"; break;
-case "Modifica i beni già inseriti":  		$messaggio = "Modify already inserted items"; break;
-case "Modifica i beni":  			$messaggio = "Modify items"; break;
-case "I beni sono stati modificati":  		$messaggio = "The items have been modified"; break;
+case "e combina":  				$messaggio = "and combine"; break;
+case "percentuale su fisso della tariffa":	$messaggio = "percentage of fixed rate"; break;
+case "percentuale su una persona della tariffa":	$messaggio = "percentage of one person of the rate"; break;
+case "non più di":  				$messaggio = "no more than"; break;
+case "non più del numero di persone":  		$messaggio = "no more than the number of people"; break;
+case "non più del numero totale di persone":  	$messaggio = "no more than the total number of people"; break;
+case "meno":  					$messaggio = "minus"; break;
+case "aggiungendo":  				$messaggio = "adding"; break;
+case "più di":  				$messaggio = "more than"; break;
+case "prezzi importati":  			$messaggio = "prices imported"; break;
+case "dalla tariffa":  				$messaggio = "from rate"; break;
+case "Cancella le carte di credito di prenotazioni passate":	$messaggio = "Delete credit cards of past reservations"; break;
+case "password per le carte di credito":  	$messaggio = "password for credit cards"; break;
+case "Cancellate":  				$messaggio = "Deleted"; break;
+case "carte di credito":  			$messaggio = "credit cards"; break;
+case "Creare":  				$messaggio = "Create"; break;
+case "persona":  				$messaggio = "person"; break;
+case "chiusa":  				$messaggio = "closed"; break;
+case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro e nessuna prenotazione non pagata":	$messaggio = "credit cards</b></div> from clients without reservations in the future and without unpaid reservations"; break;
+case "presenti in data":  			$messaggio = "present on"; break;
+case "comprese partenze":  			$messaggio = "including departures"; break;
+case "escludere_da_totale_percentuale":  	$messaggio = "exclude_from_percentage_total"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
